@@ -1,20 +1,7 @@
 import json
-from typing import BinaryIO, Dict, Optional, Type
+from typing import BinaryIO, Dict, List, NamedTuple, Optional, Type, Union
 
-from mindee.documents import (
-    CropperV1,
-    CustomV1,
-    FinancialDocumentV1,
-    FinancialV1,
-    InvoiceV3,
-    InvoiceV4,
-    PassportV1,
-    ProofOfAddressV1,
-    ReceiptV3,
-    ReceiptV4,
-    fr,
-    us,
-)
+from mindee import documents
 from mindee.documents.base import Document, TypeDocument
 from mindee.documents.config import DocumentConfig, DocumentConfigDict
 from mindee.endpoints import OTS_OWNER, CustomEndpoint, HTTPException, StandardEndpoint
@@ -23,8 +10,9 @@ from mindee.input.sources import (
     Base64Input,
     BytesInput,
     FileInput,
-    InputSource,
+    LocalInputSource,
     PathInput,
+    UrlInputSource,
 )
 from mindee.logger import logger
 from mindee.response import PredictResponse
@@ -36,13 +24,13 @@ def get_bound_classname(type_var) -> str:
 
 
 class DocumentClient:
-    input_doc: InputSource
+    input_doc: Union[LocalInputSource, UrlInputSource]
     doc_configs: DocumentConfigDict
     raise_on_error: bool = True
 
     def __init__(
         self,
-        input_doc: InputSource,
+        input_doc: Union[LocalInputSource, UrlInputSource],
         doc_configs: DocumentConfigDict,
         raise_on_error: bool,
     ):
@@ -87,7 +75,7 @@ class DocumentClient:
             This performs a cropping operation on the server and will increase response time.
         """
         bound_classname = get_bound_classname(document_class)
-        if bound_classname != CustomV1.__name__:
+        if bound_classname != documents.CustomV1.__name__:
             endpoint_name = get_bound_classname(document_class)
         elif endpoint_name is None:
             raise RuntimeError(
@@ -121,12 +109,13 @@ class DocumentClient:
 
         doc_config = self.doc_configs[config_key]
         doc_config.check_api_keys()
-        if page_options and self.input_doc.is_pdf():
-            self.input_doc.process_pdf(
-                page_options.operation,
-                page_options.on_min_pages,
-                page_options.page_indexes,
-            )
+        if not isinstance(self.input_doc, UrlInputSource):
+            if page_options and self.input_doc.is_pdf():
+                self.input_doc.process_pdf(
+                    page_options.operation,
+                    page_options.on_min_pages,
+                    page_options.page_indexes,
+                )
         return self._make_request(
             document_class, doc_config, include_words, close_file, cropper
         )
@@ -154,8 +143,7 @@ class DocumentClient:
 
         if not response.ok and self.raise_on_error:
             raise HTTPException(
-                "API %s HTTP error: %s"
-                % (response.status_code, json.dumps(dict_response))
+                f"API {response.status_code} HTTP error: {json.dumps(dict_response)}"
             )
         return PredictResponse[TypeDocument](
             http_response=dict_response,
@@ -166,7 +154,14 @@ class DocumentClient:
 
     def close(self) -> None:
         """Close the file object."""
-        self.input_doc.file_object.close()
+        if not isinstance(self.input_doc, UrlInputSource):
+            self.input_doc.file_object.close()
+
+
+class ConfigSpec(NamedTuple):
+    doc_class: Type[Document]
+    url_name: str
+    version: str
 
 
 class Client:
@@ -192,118 +187,119 @@ class Client:
         self.api_key = api_key
         self._init_default_endpoints()
 
+    def _standard_doc_config(
+        self, klass: Type[Document], url_name: str, version: str
+    ) -> DocumentConfig:
+        return DocumentConfig(
+            document_class=klass,
+            endpoints=[
+                StandardEndpoint(
+                    url_name=url_name, version=version, api_key=self.api_key
+                )
+            ],
+        )
+
     def _init_default_endpoints(self) -> None:
-        self._doc_configs = {
-            (OTS_OWNER, InvoiceV3.__name__): DocumentConfig(
-                document_type="invoice_v3",
-                document_class=InvoiceV3,
-                endpoints=[
-                    StandardEndpoint(
-                        url_name="invoices", version="3", api_key=self.api_key
-                    )
-                ],
+        configs: List[ConfigSpec] = [
+            ConfigSpec(
+                doc_class=documents.InvoiceV3,
+                url_name="invoices",
+                version="3",
             ),
-            (OTS_OWNER, InvoiceV4.__name__): DocumentConfig(
-                document_type="invoice_v4",
-                document_class=InvoiceV4,
-                endpoints=[
-                    StandardEndpoint(
-                        url_name="invoices", version="4", api_key=self.api_key
-                    )
-                ],
+            ConfigSpec(
+                doc_class=documents.InvoiceV4,
+                url_name="invoices",
+                version="4",
             ),
-            (OTS_OWNER, ReceiptV3.__name__): DocumentConfig(
-                document_type="receipt_v3",
-                document_class=ReceiptV3,
-                endpoints=[
-                    StandardEndpoint(
-                        url_name="expense_receipts", version="3", api_key=self.api_key
-                    )
-                ],
+            ConfigSpec(
+                doc_class=documents.ReceiptV3,
+                url_name="expense_receipts",
+                version="3",
             ),
-            (OTS_OWNER, ReceiptV4.__name__): DocumentConfig(
-                document_type="receipt_v4",
-                document_class=ReceiptV4,
-                endpoints=[
-                    StandardEndpoint(
-                        url_name="expense_receipts", version="4", api_key=self.api_key
-                    )
-                ],
+            ConfigSpec(
+                doc_class=documents.ReceiptV4,
+                url_name="expense_receipts",
+                version="4",
             ),
-            (OTS_OWNER, FinancialV1.__name__): DocumentConfig(
-                document_type="financial_doc",
-                document_class=FinancialV1,
-                endpoints=[
-                    StandardEndpoint(
-                        url_name="invoices", version="3", api_key=self.api_key
-                    ),
-                    StandardEndpoint(
-                        url_name="expense_receipts", version="3", api_key=self.api_key
-                    ),
-                ],
+            ConfigSpec(
+                doc_class=documents.FinancialDocumentV1,
+                url_name="financial_document",
+                version="1",
             ),
-            (OTS_OWNER, FinancialDocumentV1.__name__): DocumentConfig(
-                document_type="financial_document",
-                document_class=FinancialDocumentV1,
-                endpoints=[
-                    StandardEndpoint(
-                        url_name="financial_document", version="1", api_key=self.api_key
-                    ),
-                ],
+            ConfigSpec(
+                doc_class=documents.PassportV1,
+                url_name="passport",
+                version="1",
             ),
-            (OTS_OWNER, PassportV1.__name__): DocumentConfig(
-                document_type="passport_v1",
-                document_class=PassportV1,
-                endpoints=[
-                    StandardEndpoint(
-                        url_name="passport", version="1", api_key=self.api_key
-                    )
-                ],
+            ConfigSpec(
+                doc_class=documents.ProofOfAddressV1,
+                url_name="proof_of_address",
+                version="1",
             ),
-            (OTS_OWNER, us.BankCheckV1.__name__): DocumentConfig(
-                document_type="bank_check_v1",
-                document_class=us.BankCheckV1,
-                endpoints=[
-                    StandardEndpoint(
-                        url_name="bank_check", version="1", api_key=self.api_key
-                    )
-                ],
+            ConfigSpec(
+                doc_class=documents.CropperV1,
+                url_name="cropper",
+                version="1",
             ),
-            (OTS_OWNER, fr.CarteGriseV1.__name__): DocumentConfig(
-                document_type="carte_grise_v1",
-                document_class=fr.CarteGriseV1,
-                endpoints=[
-                    StandardEndpoint(
-                        url_name="carte_grise", version="1", api_key=self.api_key
-                    )
-                ],
+            ConfigSpec(
+                doc_class=documents.us.BankCheckV1,
+                url_name="bank_check",
+                version="1",
             ),
-            (OTS_OWNER, ProofOfAddressV1.__name__): DocumentConfig(
-                document_type="proof_of_address_v1",
-                document_class=ProofOfAddressV1,
-                endpoints=[
-                    StandardEndpoint(
-                        url_name="proof_of_address", version="1", api_key=self.api_key
-                    )
-                ],
+            ConfigSpec(
+                doc_class=documents.fr.CarteGriseV1,
+                url_name="carte_grise",
+                version="1",
             ),
-            (OTS_OWNER, CropperV1.__name__): DocumentConfig(
-                document_type="cropper_v1",
-                document_class=CropperV1,
-                endpoints=[
-                    StandardEndpoint(
-                        url_name="cropper", version="1", api_key=self.api_key
-                    )
-                ],
+            ConfigSpec(
+                doc_class=documents.fr.IdCardV1,
+                url_name="idcard_fr",
+                version="1",
             ),
-        }
+            ConfigSpec(
+                doc_class=documents.fr.CarteVitaleV1,
+                url_name="carte_vitale",
+                version="1",
+            ),
+            ConfigSpec(
+                doc_class=documents.fr.BankAccountDetailsV1,
+                url_name="bank_account_details",
+                version="1",
+            ),
+            ConfigSpec(
+                doc_class=documents.ShippingContainerV1,
+                url_name="shipping_containers",
+                version="1",
+            ),
+            ConfigSpec(
+                doc_class=documents.eu.LicensePlateV1,
+                url_name="license_plates",
+                version="1",
+            ),
+        ]
+        for config in configs:
+            config_key = (OTS_OWNER, config.doc_class.__name__)
+            self._doc_configs[config_key] = self._standard_doc_config(
+                config.doc_class, config.url_name, config.version
+            )
+        self._doc_configs[OTS_OWNER, documents.FinancialV1.__name__] = DocumentConfig(
+            document_class=documents.FinancialV1,
+            endpoints=[
+                StandardEndpoint(
+                    url_name="invoices", version="3", api_key=self.api_key
+                ),
+                StandardEndpoint(
+                    url_name="expense_receipts", version="3", api_key=self.api_key
+                ),
+            ],
+        )
 
     def add_endpoint(
         self,
         account_name: str,
         endpoint_name: str,
         version: str = "1",
-        document_class: Type[Document] = CustomV1,
+        document_class: Type[Document] = documents.CustomV1,
     ) -> "Client":
         """
         Add a custom endpoint, created using the Mindee API Builder.
@@ -404,3 +400,21 @@ class Client:
             doc_configs=self._doc_configs,
             raise_on_error=self.raise_on_error,
         )
+
+    def doc_from_url(
+        self,
+        url: str,
+    ) -> DocumentClient:
+        """
+        Load a document from an URL.
+
+        :param url: Raw byte input
+        """
+        input_doc = UrlInputSource(
+            url,
+        )
+        return DocumentClient(
+            input_doc=input_doc,
+            doc_configs=self._doc_configs,
+            raise_on_error=self.raise_on_error,
+        )
