@@ -1,6 +1,7 @@
 from mindee.documents import fr, us
 from mindee.documents.cropper import CropperV1, TypeCropperV1
 from mindee.documents.custom import CustomV1, TypeCustomV1
+from mindee.documents.eu import LicensePlateV1, TypeLicensePlateV1
 from mindee.documents.financial import (
     FinancialDocumentV1,
     FinancialV1,
@@ -11,3 +12,7 @@ from mindee.documents.invoice import InvoiceV3, InvoiceV4, TypeInvoiceV3, TypeIn
 from mindee.documents.passport import PassportV1, TypePassportV1
 from mindee.documents.proof_of_address import ProofOfAddressV1, TypeProofOfAddressV1
 from mindee.documents.receipt import ReceiptV3, ReceiptV4, TypeReceiptV3, TypeReceiptV4
+from mindee.documents.shipping_container import (
+    ShippingContainerV1,
+    TypeShippingContainerV1,
+)
