@@ -1,4 +1,4 @@
-from typing import Dict, List, Tuple, Type
+from typing import Dict, List, Optional, Tuple, Type
 
 from mindee.documents.base import Document
 from mindee.endpoints import API_KEY_ENV_NAME, Endpoint
@@ -7,15 +7,15 @@ _docT = Type[Document]
 
 
 class DocumentConfig:
-    document_type: str
+    document_type: Optional[str]
     endpoints: List[Endpoint]
     document_class: _docT
 
     def __init__(
         self,
-        document_type: str,
         document_class: _docT,
         endpoints: List[Endpoint],
+        document_type: Optional[str] = None,
     ):
         self.document_type = document_type
         self.document_class = document_class
@@ -27,7 +27,7 @@ class DocumentConfig:
             if not endpoint.api_key:
                 raise RuntimeError(
                     (
-                        f"Missing API key for '{self.document_type}',"
+                        f"Missing API key for '{endpoint.url_name} v{endpoint.version}',"
                         "check your Client configuration.\n"
                         "You can set this using the "
                         f"'{API_KEY_ENV_NAME}' environment variable."
